import SimpleForm from "@/components/form/simple_form";
import { Button, Form, FormInstance, InputNumber, Select, Space } from "antd";
import React, { useEffect } from "react";
import { formConfig } from "./sku_add_config";
import { inject, observer } from "mobx-react";
import { MinusCircleOutlined } from "@ant-design/icons";
import { Store } from "antd/es/form/interface";
const { Option } = Select;

const SkuAdd = (props: Store) => {
  const formRef = React.useRef<FormInstance>(null);
  const { skuStore } = props;
  useEffect(() => {
    skuStore.getSkuSpecCat();
  });
  const create = () => {
    let data = formRef.current?.getFieldsValue();
    let obj = {...data}
    let files:any = []
    obj.sku_thumb = data.sku_thumb[0].url;
    
    if (data.files && data.files.length > 0) {
      data.files.forEach((v)=>{
        if(v.url){
          files.push({
            file_name:v.fileName,
            file_url:v.url,
            file_type:1,
          })
        }
      })
    }
    obj.files = files
    skuStore.add(obj);
  };
  return (
    <div style={{ margin: "0 auto", overflowX: "auto", height: "80%" }}>
      <div
        style={{
          padding: "10px",
          marginLeft: 18,
          marginBottom: 10,
          fontSize: "1.2rem",
          display: "flex",
          justifyContent: "space-between",
        }}
      >
        <span>商品添加</span>
        <Button onClick={() => formRef.current?.submit()}>提交</Button>
      </div>
      <SimpleForm
        formName={"tag_form"}
        formRef={formRef}
        colProps={20}
        span={2}
        childrenPosi={true}
        onFinish={() => create()}
        createCallback={() => {
          // formRef.current?.setFieldsValue(record);
        }}
        formDatas={formConfig as any}
      >
        <Form.List name="sku_price" initialValue={[{}]}>
          {(fields, { add, remove }) => {
            return (
              <>
                {fields.map(({ key, name }) => (
                  <Space
                    key={key}
                    style={{
                      display: "flex",
                      border: "1px solid #f3f3f3",
                      padding: "10px",
                      margin: "10px",
                      alignItems: "center",
                    }}
                  >
                    <Form.Item
                      label="规格"
                      style={{ margin: "0px" }}
                      labelCol={{ span: 10, offset: 0 }}
                      name={[name, "sku_spec_id"]}
                      rules={[{ required: true, message: "规格" }]}
                    >
                      <Select placeholder="" style={{ width: "100px" }}>
                        {skuStore.skuSpec?.map((v: any) => {
                          return (
                            <Option key={v.identity} value={v.identity}>
                              {v.spec_name}
                            </Option>
                          );
                        })}
                      </Select>
                    </Form.Item>
                    <Form.Item
                      label="零售价"
                      style={{ margin: "0px" }}
                      labelCol={{ span: 12, offset: 0 }}
                      name={[name, "sku_price"]}
                      rules={[{ required: true, message: "零售价" }]}
                    >
                      <InputNumber placeholder="零售价" />
                    </Form.Item>
                    <Form.Item
                      label="优惠价"
                      name={[name, "sku_sale_price"]}
                      style={{ margin: "0px" }}
                      labelCol={{ span: 12, offset: 0 }}
                      rules={[{ required: true, message: "优惠价" }]}
                    >
                      <InputNumber placeholder="优惠价" />
                    </Form.Item>
                    <Form.Item
                      name={[name, "sku_stock"]}
                      style={{ margin: "0px" }}
                      labelCol={{ span: 12, offset: 0 }}
                      label="库存"
                      rules={[{ required: true, message: "库存" }]}
                    >
                      <InputNumber placeholder="库存" />
                    </Form.Item>
                    <MinusCircleOutlined
                      onClick={() => remove(name)}
                      style={{ marginLeft: "20px" }}
                    />
                  </Space>
                ))}
                <Form.Item style={{ marginTop: "10px" }}>
                  <Button
                    type="dashed"
                    onClick={() => {
                      add();
                    }}
                  >
                    添加规格
                  </Button>
                </Form.Item>
              </>
            );
          }}
        </Form.List>
      </SimpleForm>
    </div>
  );
};

export default inject("skuStore")(observer(SkuAdd));
